@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20250228';
+our $VERSION = '0.20250331';
 
-# Table last modified: 2025-02-28
+# Table last modified: 2025-03-31
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[0-2]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -63,13 +63,13 @@ our %ZIP_TABLE = (
     '057' => '(?:85(?:11|58))',
     '058' => '(?:(?:0292|8501))',
     '059' => '(?:(?:1(?:39[2-6]|59[2-6]|69[23]|292)|0(?:59[2568]|99[3578]|49[236])|2(?:[14]92|598)|8[67]01|3195))',
-    '060' => '(?:8(?:5(?:[38]\d|4[1-9]|[12][0-35-9]|6[0135-9]|7[02-9]|0[1-68]|5[0-46-9])|6(?:1\d|5[14-68]|8[6-8]|7[016-8]|0[1-9]|6[16-8]|2[13-57-9]|4[0-46-9]|3[0-24-9])|7(?:11|67|9[5-7]|7[146]|0[35-7]|2[15])|406))',
+    '060' => '(?:8(?:5(?:[38]\d|4[1-9]|[12][0-35-9]|6[0135-9]|7[02-9]|0[1-68]|5[0-46-9])|6(?:1\d|5[14-68]|8[6-8]|7[016-8]|0[1-9]|6[16-8]|4[0-47-9]|2[13-57-9]|3[0-24-9])|7(?:11|9[5-7]|7[146]|6[67]|0[35-7]|2[15])|406))',
     '061' => '(?:(?:1(?:39[2-6]|49[236-8]|19[256])|0(?:29[2356]|59[25]|692)|3(?:29[2-6]|197|692)|2292|8501))',
     '062' => '(?:8(?:6(?:86|1[278]|0[1-357-9]|3[0135]|2[24]|4[12]|6[68])|5(?:01|20|7[025]|5[58]|3[029]|1[01467])))',
     '063' => '(?:8(?:5(?:22|0[17]|5[58]|[18][05])|6(?:0[1-36-8]|1[12]|4[15])))',
     '064' => '(?:8(?:5(?:2[1-46]|1[024-689]|6[0-7]|4[0-356]|5[014-8]|8[169]|0[23569]|7[0157]|3[35-7])|6(?:09|2[0-2489]|4[4589]|1[01]|3[039])|798))',
     '065' => '(?:8(?:5(?:[34]3|22|67|78|1[018]|5[058]|0[18])|6(?:0[19]|3[139]|1[0-2])))',
-    '066' => '(?:8(?:5(?:20|33|1[025]|7[07]|6[67]|8[58]|5[0578]|0[1248])|6(?:01|22|49|55|86|3[379]|6[068]|1[01])|7(?:11|65|87)))',
+    '066' => '(?:8(?:5(?:20|33|67|1[025]|7[07]|8[58]|5[0578]|0[1248])|6(?:01|22|49|55|86|3[379]|6[068]|1[01])|7(?:11|65|87)))',
     '067' => '(?:8(?:5(?:[05]1|47|85|6[45])|674))',
     '068' => '(?:(?:8(?:6(?:[03]9|42|50|6[068]|8[68])|5(?:11|88|5[058]))|1(?:19[2-5]|292)|0(?:194|492)|219[2-4]))',
     '069' => '(?:(?:1(?:29[236-8]|39[2-5])|85(?:[01]1|[58]5|33)|029[23]))',
@@ -107,8 +107,8 @@ our %ZIP_TABLE = (
     '101' => '(?:8(?:6(?:8[28]|0[356]|5[146]|6[57]|2[1246-9]|3[01367]|7[026]|4[235-8]|1[01679])|4(?:1[0568]|6[0-246]|7[057]|4[13-68]|3[0379]|8[05]|0[58]|2[12459]|5[0169])|5(?:3[0-245]|6[1258]|7[59]|4[28]|1[25]|0[249]|8[0569]|2[0-578]|5[24589])|3(?:5[013589]|8[38]|4[367]|0[17-9]|3[3568]|1[0138]|2[3-69]|7[258]|6[267])|7(?:0[137]|1[0-25-8])|9(?:41|50|7[37]|8[36])|2(?:28|0[14]|1[0359])|0(?:11|5[04]|0[128])|1(?:01|89)))',
     '102' => '(?:8(?:1(?:1[0-357-9]|2[02-58]|8[124-8]|0[239]|5[0-25]|3[0-289]|7[0-25-8]|9[0-5]|4[0-24]|6[016])|5(?:0[2-468]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|1[0-3569]|6[013-79]|8[023568])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|4[0158]|2[0146]|8[489]|3[037]|1[01479])|2(?:5[015]|3[0-24-68]|6[045]|8[28]|7[2-57]|2[1-68]|[01][15]|4[016])|3(?:7[0-37]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|4[139]|5[0367]|0[1359])|0(?:30|77|8[0-358]|2[256]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
     '103' => '(?:8(?:2(?:5[0-2569]|3[0-689]|7[036-8]|0[1-68]|8[2457]|1[0-248]|6[0156]|2[124589]|4[013578])|4(?:7[0-3]|0[1-57]|6[0-24-68]|4[38]|3[0-589]|1[0-79]|2[24-7]|8[02457-9]|5[016])|3(?:70|0[1378]|8[0348]|4[15-7]|1[1-478]|5[0-248]|6[036]|3[01357-9]|2[13-58])|5(?:1[0-257]|5[12468]|7[17]|2[0-25]|0[1-356]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|3[169]|7[67]|6[068]|8[0469])|0[01]1))',
-    '104' => '(?:(?:8(?:1(?:2[2-589]|5[018]|6[12578]|8[389]|7[014-689]|4[2578]|3[0-589]|1[0-24-8]|0[124589])|3(?:1[023579]|7[07-9]|2[458]|8[013689]|6[35]|5[0167]|3[02358]|4[0-5]|0[12467])|4(?:5[06]|3[013589]|1[369]|0[24578]|8[168]|2[0-469]|6[078]|4[02-49])|5(?:33|77|2[136-8]|4[357]|5[014-689]|6[068]|1[078]|8[1458]|0[1256])|2(?:38|40|71|6[26]|5[124578]|0[568]|8[0-59]|1[0-28])|6(?:14|78|5[06]|8[05]|6[15])|0(?:55|77|1[01]|0[1-37]))|6241))',
-    '105' => '(?:(?:8(?:4(?:7[0-257]|8[2-6]|5[1-36-8]|3[13-7]|0[1-478]|[46][014-9]|2[0347-9]|1[0-24-9])|5(?:6[03578]|1[0-2568]|0[1-357-9]|5[013-8]|8[0-57-9]|7[4-9]|2[1-57-9]|3[0457]|4[03-6])|6(?:7[026-8]|3[04]|8[01569]|6[0568]|1[013-5]|2[0135-7]|5[468]|4[0-24]|0[3468])|3(?:1\d|3[01358]|0[1-9]|2[235])|0(?:10|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[267]))|7(?:0(?:[58]0|77)|36[05-7]|444)|6[09]50))',
+    '104' => '(?:(?:8(?:1(?:2[2-589]|5[018]|6[12578]|8[389]|7[014-689]|4[2578]|3[0-589]|1[0-24-8]|0[124589])|3(?:1[023579]|6[356]|7[07-9]|2[458]|8[013689]|5[0167]|3[02358]|4[0-5]|0[12467])|4(?:5[06]|3[013589]|1[369]|0[24578]|8[168]|2[0-469]|6[078]|4[02-49])|5(?:33|77|2[136-8]|4[357]|5[014-689]|6[068]|1[078]|8[1458]|0[1256])|2(?:38|40|71|6[26]|5[124578]|0[568]|8[0-59]|1[0-28])|6(?:14|78|5[06]|8[05]|6[15])|0(?:55|77|1[01]|0[1-37]))|6241))',
+    '105' => '(?:(?:8(?:4(?:7[0-257]|8[2-6]|5[1-36-8]|3[13-7]|0[1-478]|[46][014-9]|2[0347-9]|1[0-24-9])|5(?:6[03578]|1[0-2568]|0[1-357-9]|5[013-8]|8[0-57-9]|7[4-9]|2[1-57-9]|3[0457]|4[03-6])|6(?:7[026-8]|3[04]|8[01569]|6[0568]|1[013-5]|2[0135-7]|5[468]|4[0-24]|0[3468])|3(?:1\d|3[01358]|0[1-9]|2[235])|0(?:10|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[267]))|7(?:0(?:[58]0|77)|36[05-7]|444)|6[09]50))',
     '106' => '(?:(?:8(?:5(?:6[0-35-79]|0[78]|3[17]|1[458]|7[135-8]|2[12]|5[0-25689]|4[145]|8[0157-9])|6(?:77|4[0-2489]|5[25]|1[16]|6[58]|3[0569]|0[18]|2[0256])|0(?:11|39|0[17])|(?:10|79)7|4(?:01|87))|6(?:1(?:61|88)|06[06])))',
     '107' => '(?:8(?:4(?:20|5[06]|7[127]|0[1-4]|1[126-9]|3[14]|8[24]|4[08]|6[038])|5(?:32|81|0[23578]|7[02]|1[146]|2[0178]|6[037]|5[0268]|4[56])|6(?:01|50|66|1[5-79]|7[46]|3[0-3689]|8[068]|2[0357])|3(?:20|4[0289]|7[013]|8[048]|3[026]|5[125])|0(?:[16]0|77|0[16])))',
     '108' => '(?:(?:8(?:5(?:2[0-35]|3[02369]|0[1-9]|6[0468]|1[0-25]|7[0135]|5[0-35-8]|4[035]|8[0-3568])|3(?:2[25689]|3[134]|1[0356]|7[2359]|8[013-689]|5[058]|6[01]|4[15]|0[13578])|2(?:8[028]|7[056]|4[0-38]|1[0-267]|0[1-36-9]|3[0-4]|5[05]|2[0245])|4(?:56|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:50|2[28]|1[125-7]|3[1-3689]|0[267]|4[0-28])|0(?:[258]0|71|[01][15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
@@ -118,7 +118,7 @@ our %ZIP_TABLE = (
     '112' => '(?:8(?:6(?:90|6[02-48]|4[245]|2[02579]|1[0-289]|7[0178]|5[0-57]|8[0-578]|0[14679]|3[0-5])|5(?:[78][0356]|4[018]|2[458]|1[124]|6[2369]|3[0138]|0[1-35689]|5[015-8])|7(?:[156]0|78|0[12])|0(?:[01]1|88)|138))',
     '113' => '(?:8(?:4(?:4[148]|7[1479]|8[3-58]|2[0-3]|1[0-358]|6[2-6]|3[13-5]|5[0169]|0[1248])|5(?:70|0[13-579]|3[04-68]|6[0-46]|4[1369]|1[02379]|2[0145]|5[1356])|6(?:77|3[38]|5[04-8]|0[1-468]|8[16]|1[0-2]|6[0-378])|7(?:01|1[0-29])|139|311))',
     '114' => '(?:8(?:5(?:95|0[1-35-8]|8[013-58]|6[0-25]|2[0-468]|7[147]|4[01356]|5[02-57]|3[0-24589]|1[02457-9])|6(?:11|86|0[2-6])))',
-    '115' => '(?:8(?:5(?:55|8[568]|1[01]|2[49])|(?:00|71)1|6(?:22|50)))',
+    '115' => '(?:8(?:5(?:55|8[68]|1[01]|2[49])|(?:00|71)1|6(?:22|50)))',
     '116' => '(?:8(?:5(?:71|6[127]|2[1-4]|5[0-46]|8[014-8]|4[0134689]|0[1-3578]|3[237])|621))',
     '120' => '(?:8(?:5(?:44|81|5[014-68]|0[17]|1[02]|7[05]|2[068]|3[0469])|60[12]))',
     '121' => '(?:8(?:5(?:77|1[025]|0[458]|8[58]|5[05]|2[01])|6(?:82|3[39]|1[01])|7(?:11|29)|080))',
@@ -130,7 +130,7 @@ our %ZIP_TABLE = (
     '132' => '(?:8(?:5(?:[18]5|5[015]|3[03]|0[137]|6[27])|6(?:01|74|[68][68])|7(?:11|3[029])))',
     '133' => '(?:8(?:5(?:[01]1|8[058]|5[238])|70[46]))',
     '134' => '(?:8(?:5(?:[15]5|20|33|7[05-7]|8[5-8]|0[237])|6(?:22|86|[14][02]|0[1-39]|3[01])|702))',
-    '135' => '(?:8(?:5(?:48|3[0-358]|7[57-9]|2[1-3578]|8[1257]|1[0-478]|5[0-24-9]|0[12458]|6[035-8])|4(?:4[0358]|2[27]|0[24]|5[18]|8[0-2]|7[037]|6[014]|1[15]|3[026])|6(?:86|0[28]|2[0-25]|6[168]|3[0-29]|7[078]|1[014-9]|5[059])|3(?:[25]0|8[3-57]|0[1368]|7[05]|6[023]|3[01]|1[0-28])|1(?:21|50|65|78|1[01458]|0[89]|3[0479]|8[01])|7(?:97|3[0-3]|2[0-37]|0[17]|1[0178])|2(?:10|2[24])|0(?:74|80)))',
+    '135' => '(?:8(?:5(?:48|3[0-358]|7[579]|2[1-3578]|8[1257]|1[0-478]|5[0-24-9]|0[12458]|6[035-8])|4(?:4[0358]|2[27]|0[24]|5[18]|8[0-2]|7[037]|6[014]|1[15]|3[026])|6(?:86|0[28]|2[0-25]|6[168]|3[0-29]|7[078]|1[014-9]|5[059])|3(?:[25]0|8[3-57]|0[1368]|7[05]|6[023]|3[01]|1[0-28])|1(?:21|50|65|78|1[01458]|0[89]|3[0479]|8[01])|7(?:97|3[0-3]|2[0-37]|0[17]|1[0178])|2(?:10|2[24])|080))',
     '136' => '(?:8(?:5(?:60|3[135]|4[03]|5[056]|8[01589]|1[2357]|7[057]|0[1257]|2[1-35])|6(?:51|8[06]|1[25]|[37][0157]|2[0267]|6[68]|4[08]|0[3578])|7(?:[23]3|11)|88[018]|405|908))',
     '137' => '(?:8(?:6(?:23|86)|08[18]|581))',
     '140' => '(?:8(?:5(?:90|4[0137-9]|3[0136-9]|7[1-46]|0[23679]|8[0346]|6[0367]|2[1-3569]|5[1248]|1[1256])|6(?:4[04]|3[0147]|2[1568]|6[013689]|7[025-8]|5[03-68]|0[12]|8[0278]|1[14-79])|7(?:88|1[015-7]|2[12]|0[279])|(?:45|81)0))',
@@ -175,7 +175,7 @@ our %ZIP_TABLE = (
     '184' => '(?:8(?:5(?:[34]3|22|95|1[015]|5[58]|7[57]|0[1-58]|8[1458])|795))',
     '185' => '(?:8(?:5(?:[24]0|33|6[27]|0[126]|1[01])|601|795))',
     '186' => '(?:8(?:6(?:50|0[1-3]|1[19]|8[068]|6[68])|5(?:19|85|0[15])|79[78]|001))',
-    '187' => '(?:8(?:5(?:40|0[2357]|3[13]|5[1358]|2[02]|6[07]|8[1578]|7[078]|1[0-28])|(?:61|70)1))',
+    '187' => '(?:8(?:5(?:40|1[028]|0[2357]|3[13]|5[1358]|2[02]|6[07]|8[1578]|7[078])|(?:61|70)1))',
     '188' => '(?:8(?:5(?:[58]5|11)|6(?:66|80)|701))',
     '189' => '(?:85(?:[01]1|20|85|5[05]))',
     '190' => '(?:(?:8(?:5(?:90|2[028]|3[015-79]|0[135-8]|6[0-256]|8[1-3689]|4[02-4]|1[013-9]|7[1-3589]|5[014578])|6(?:09|66|8[0168]))|129[23578]|0192))',
@@ -191,7 +191,7 @@ our %ZIP_TABLE = (
     '202' => '(?:85(?:20|85|5[58]))',
     '203' => '(?:8(?:5(?:[12]1|55|8[58])|601|739))',
     '204' => '(?:85(?:[01]1|22|33|67|5[58]|8[589]))',
-    '205' => '(?:8(?:5(?:11|55|0[13])|6(?:60|0[1467])))',
+    '205' => '(?:8(?:5(?:11|55|0[13])|6(?:60|0[147])))',
     '206' => '(?:8(?:5(?:30|77|4[03]|2[025]|0[25]|8[568]|1[0-25]|6[167]|5[15])|6(?:[01]1|[68]6)))',
     '207' => '(?:85(?:[18]5|01))',
     '208' => '(?:85(?:[58]5|0[1-3]))',
@@ -239,7 +239,7 @@ our %ZIP_TABLE = (
     '257' => '(?:85(?:[23]3|11|55|66|77|8[458]|0[12]))',
     '258' => '(?:(?:85(?:11|77|85|3[38]|0[16])|0195))',
     '259' => '(?:(?:0(?:1(?:9[2-467]|8[01])|39[2356])|1(?:1(?:8[5-8]|9[236-8])|292)))',
-    '260' => '(?:8(?:6(?:0[13467]|1[0-389]|8[1258]|2[0-24-79]|5[46]|4[2578]|6[0-35-8]|7[0-357]|3[135-7])|5(?:40|7[0257]|5[1257-9]|8[0568]|1[0-35-8]|0[1-35-9]|3[4-68]|6[0-467]|2[13478])|7(?:33|1[02357]|0[137]|2[02])))',
+    '260' => '(?:8(?:6(?:0[13467]|1[0-389]|8[1258]|5[46]|4[2578]|6[0-35-8]|7[0-357]|2[0-24-7]|3[135-7])|5(?:40|7[0257]|5[1257-9]|8[0568]|1[0-35-8]|0[1-35-9]|3[4-68]|6[0-467]|2[13478])|7(?:33|1[02357]|0[137]|2[02])))',
     '261' => '(?:8(?:5(?:1[0-35]|6[0168]|3[0359]|8[0-25-8]|7[57]|5[0248]|0[1-478]|4[145]|2[0-28])|6(?:86|0[1-39])|733))',
     '262' => '(?:8(?:5(?:0[26]|1[0-24])|733))',
     '263' => '(?:8(?:5(?:[12]2|33|77|6[06]|8[58]|5[05]|0[56])|733))',
@@ -310,7 +310,7 @@ our %ZIP_TABLE = (
     '334' => '(?:8501)',
     '335' => '(?:8(?:5(?:10|22|33|[58][58]|0[12])|6(?:55|66)))',
     '336' => '(?:8(?:5(?:40|6[14]|1[25]|2[1-36]|8[67]|[05][58])|6(?:[36]6|55)|760))',
-    '337' => '(?:85(?:[58]6|32|70|0[127]))',
+    '337' => '(?:85(?:[58]6|32|70|0[17]))',
     '338' => '(?:8(?:5(?:8[056]|1[0-35]|2[3-5]|7[057]|0[3-68]|6[67]|5[1578]|3[18]|4[01])|6(?:30|86)))',
     '339' => '(?:8(?:5(?:21|39|66|85|0[13]|5[18]|1[01])|6(?:01|86)))',
     '340' => '(?:(?:8(?:5(?:33|77|5[015]|2[04]|0[19]|8[58]|6[078]|1[01])|6(?:59|86|1[01]))|0(?:19[2-4]|295)))',
@@ -350,7 +350,7 @@ our %ZIP_TABLE = (
     '374' => '(?:(?:8(?:5(?:01|20|33|55|77|88|1[0-28])|6(?:11|22|40|86|0[18]))|019[23]))',
     '375' => '(?:8(?:50[1-7]|60[1-4]))',
     '376' => '(?:(?:8(?:5(?:31|85|1[056]|2[38]|5[58]|0[12])|6(?:86|6[68]))|0(?:19[2-4]|39[27])))',
-    '377' => '(?:(?:0(?:8(?:8[23]|9[2-46-8])|2(?:80|9[2-4])|19[235]|39[25]|49[24]|792)|8(?:5(?:20|33|55|77|1[013]|6[67]|0[1-38]|8[58])|616)|1(?:79[2-7]|39[235]|59[3-5]|69[235])))',
+    '377' => '(?:(?:0(?:8(?:8[23]|9[2-46-8])|2(?:80|9[2-4])|19[235]|39[25]|49[24]|792)|8(?:5(?:20|33|55|77|1[03]|6[67]|0[1-38]|8[58])|616)|1(?:79[2-7]|39[235]|59[3-5]|69[235])))',
     '378' => '(?:(?:0498|8501))',
     '379' => '(?:(?:2(?:1(?:8[014-7]|9[2-578])|39[258]|29[28])|1(?:29[78]|[16]92|393|498)|0(?:19[235-7]|292)))',
     '380' => '(?:8(?:5(?:0[1-35-8]|8[0-689]|2[014-6]|7[0235-7]|6[015-8]|5[0-3578]|4[03-6]|1[0-25689]|3[013-9])|6(?:55|77|0[158]|2[25]|8[268]|6[068]|4[08]|1[0-24]|3[039])|7(?:10|9[4-8])))',
@@ -442,7 +442,7 @@ our %ZIP_TABLE = (
     '468' => '(?:8(?:5(?:51|2[02]|0[1-357]|1[0-4]|8[58]|3[1-467])|626))',
     '469' => '(?:879[367])',
     '470' => '(?:(?:0(?:1(?:9[2-8]|8[68])|29[2-57]|39[2-6]|49[2356]|592)|2(?:19[1-35-8]|39[2-58]|29[26-8]|49[23])|1(?:19[2-68]|29[2-6])|3(?:29[56]|495)))',
-    '471' => '(?:8(?:5(?:7[1-4]|6[056]|3[0-25-7]|0[1-36-8]|1[0-35-8]|8[58]|5[05]|2[1257])|60[1-39]))',
+    '471' => '(?:8(?:5(?:7[1-4]|3[05-7]|0[1-36-8]|1[0-35-8]|8[58]|5[05]|2[1257]|6[56])|60[1-39]))',
     '472' => '(?:8(?:6(?:[68]6|39)|5[58]5))',
     '473' => '(?:85[01]1)',
     '474' => '(?:8(?:5(?:35|43|8[01458]|5[0578]|1[01]|0[1-35])|6(?:[05]1|42|[68][68]|1[01])|7(?:10|66|77|0[17])))',
@@ -462,8 +462,8 @@ our %ZIP_TABLE = (
     '488' => '(?:8(?:5(?:[58]5|01|20|78)|6(?:55|66|8[68])))',
     '489' => '(?:8(?:5(?:20|67|85|5[05]|1[01])|6(?:[58]0|11|4[25])|450|701))',
     '490' => '(?:1(?:29[2-6]|19[2-48]|392))',
-    '491' => '(?:(?:8(?:5(?:85|1[2356]|5[1358]|7[15-7]|0[125689]|6[12]|2[68]|3[1-35])|6(?:0[18]|1[0-2]|8[68]))|0(?:39[2-5]|192)))',
-    '492' => '(?:8(?:5(?:2[013589]|4[0-25-8]|0[12]|1[023])|6(?:[05]1|46|2[128]|8[0-256])))',
+    '491' => '(?:(?:8(?:5(?:85|1[2356]|5[1358]|7[15-7]|0[125689]|6[12]|2[68]|3[1-35])|6(?:0[18]|1[0-2]|8[68])|792)|0(?:39[2-5]|192)))',
+    '492' => '(?:8(?:5(?:2[013589]|1[02]|4[025-8]|0[12])|6(?:[05]1|46|2[128]|8[0-256])))',
     '494' => '(?:8(?:5(?:1[16]|0[1257])|6(?:[01]1|86)))',
     '495' => '(?:8(?:5(?:31|0[15]|1[017])|601))',
     '496' => '(?:8(?:5(?:75|3[1-57]|0[138]|5[58])|6(?:01|48|86|3[39])|720))',
@@ -491,7 +491,7 @@ our %ZIP_TABLE = (
     '519' => '(?:(?:0(?:19[3-8]|49[2357]|59[2-5]|292|393|696)|3(?:69[2-6]|[24]92)|2(?:59[23]|[17]92)|439[2-6]|529[23]|1192))',
     '520' => '(?:(?:8(?:5(?:[23]0|01|67|8[0568]|1[0-356]|7[057]|5[058])|6(?:39|66))|3(?:1(?:9[45]|8[02589])|08[0-58]|28[12589]|49[23]|393)|2(?:39[2-5]|59[24-6]|19[24]|492)|1(?:1(?:88|92)|[2568]92|49[25])|0(?:2(?:87|92)|58[08])))',
     '521' => '(?:(?:1(?:29[25]|39[28]|192)|8(?:60|5[01])1|0[23]92))',
-    '522' => '(?:(?:8(?:5(?:11|0[135]|4[03]|3[39]|8[58]|2[023])|6(?:55|66))|029[27]))',
+    '522' => '(?:(?:8(?:5(?:11|0[135]|4[03]|3[39]|8[58]|2[023])|6(?:55|66))|0297))',
     '523' => '(?:8(?:5(?:[23]3|5[58]|1[05]|0[1-37])|651))',
     '524' => '(?:85(?:01|24|77|85))',
     '525' => '(?:85(?:77|1[015]|6[67]|2[0-256]|[58][58]|0[125]))',
@@ -505,7 +505,7 @@ our %ZIP_TABLE = (
     '533' => '(?:8(?:5(?:33|85|5[58]|0[12])|651))',
     '534' => '(?:85(?:11|85|0[12]))',
     '535' => '(?:85(?:[58]5|01))',
-    '536' => '(?:8(?:5(?:10|36|67|0[1358]|8[58]|2[237]|5[038])|686))',
+    '536' => '(?:8(?:5(?:10|36|67|2[2357]|0[1358]|8[58]|5[038])|686))',
     '537' => '(?:8(?:(?:50|91)1|686))',
     '538' => '(?:8(?:5(?:[58]5|01|10)|6(?:[68]6|55)))',
     '539' => '(?:8794)',
@@ -558,7 +558,7 @@ our %ZIP_TABLE = (
     '589' => '(?:85(?:11|85|0[12]))',
     '590' => '(?:(?:8(?:5(?:40|2[27-9]|7[67]|6[078]|1[157]|8[589]|[35][01]|0[1-35])|686)|0(?:4(?:9[3-6]|8[12])|592)))',
     '591' => '(?:8(?:5(?:11|55|0[125])|701))',
-    '592' => '(?:85(?:50|85))',
+    '592' => '(?:85(?:43|50|85))',
     '593' => '(?:8504)',
     '594' => '(?:(?:8(?:50[12]|686)|119[28]))',
     '595' => '(?:8(?:6(?:50|86)|5[58]5))',
@@ -616,7 +616,7 @@ our %ZIP_TABLE = (
     '650' => '(?:8(?:5(?:1[015]|6[05-7]|5[01589]|2[0-258]|0[1-356]|3[0369]|7[015-7]|8[04-689]|4[36])|6(?:[68][06]|7[07])|7(?:87|94)))',
     '651' => '(?:(?:8(?:5(?:[58]5|67|70|1[124]|0[12]|2[56])|798)|2(?:1(?:9[467]|8[0178])|49[24]|295)|01(?:7[0-278]|9[35]|8[578])|1(?:195|596)))',
     '652' => '(?:85(?:[17]0|01|85|5[05]))',
-    '653' => '(?:8(?:5(?:70|85)|76[267]))',
+    '653' => '(?:8(?:5(?:70|85)|76[67]))',
     '654' => '(?:(?:85(?:11|70|85)|019[2358]))',
     '655' => '(?:8570)',
     '656' => '(?:(?:1(?:59[28]|395|792)|2(?:[2-4]92|193)|8(?:6[568]6|555)|0(?:492|595)))',
@@ -718,7 +718,7 @@ our %ZIP_TABLE = (
     '757' => '(?:(?:8(?:5(?:11|85)|6(?:34|86))|029[28]))',
     '758' => '(?:8(?:6(?:15|86|4[58])|5(?:[58]5|70)))',
     '759' => '(?:(?:(?:22|55)92|029[2357]|419[2468]|659[25]))',
-    '760' => '(?:8(?:5(?:90|4[5-7]|5[0-2457-9]|3[0346-9]|1[1-8]|2[0-57]|6[0-246-9]|8[0235689]|7[0-69]|0[2-578])|6(?:71|8[6-8]|6[0178]|3[04689]|5[05]|1[0458]|4[48]|2[013-6]|0[13478])))',
+    '760' => '(?:8(?:5(?:90|5[0-2457-9]|3[0346-9]|1[1-8]|4[25-7]|2[0-57]|6[0-246-9]|8[0235689]|7[0-69]|0[2-578])|6(?:71|8[6-8]|6[0178]|3[04689]|5[05]|1[0458]|4[48]|2[013-6]|0[13478])))',
     '761' => '(?:(?:8(?:5(?:[014]1|20|8[124-689]|7[78]|6[5-7]|3[38]|5[0158])|601|777)|0(?:1(?:8[5-9]|9[2-8])|39[3-7]|49[23]|79[35]|692)|4(?:4(?:89|9[2-8])|3(?:88|9[235-8])|19[2-4])|1(?:79[2-5]|49[2-4]|592)|2(?:39[2356]|49[23])))',
     '762' => '(?:8(?:5(?:50|1[015]|0[23578])|60[12]))',
     '763' => '(?:8(?:5(?:0[1-478]|1[0-368])|60[358]))',
@@ -866,7 +866,7 @@ our %ZIP_TABLE = (
     '905' => '(?:(?:0(?:59[2-6]|79[2-6]|49[24]|292|695)|8(?:5(?:01|12|40|85)|6(?:11|68))|1(?:[23]92|495)|2192))',
     '906' => '(?:(?:8(?:5(?:01|50)|601)|0[256]92))',
     '907' => '(?:(?:850[1-3]|1[28]92))',
-    '910' => '(?:(?:8(?:5(?:3[0235-9]|4[0-58]|8\d|0[1-47-9]|5[0-57-9]|1[0-79]|6[0-24-8]|2[0-8]|7[15689])|6(?:22|30|6[056]|0[136]|5[05]|8[068]|7[08]|1[01])|730)|1(?:19[2-5]|29[2-5]|392)|0(?:29[236-8]|39[23])|(?:23|36)92|419[35-8]))',
+    '910' => '(?:(?:8(?:5(?:3[0235-9]|4[0-58]|1[0-35-79]|8\d|0[1-47-9]|5[0-57-9]|6[0-24-8]|2[0-8]|7[15689])|6(?:22|30|6[056]|0[136]|5[05]|8[068]|7[08]|1[01])|730)|1(?:19[2-5]|29[2-5]|392)|0(?:29[236-8]|39[23])|(?:23|36)92|419[35-8]))',
     '911' => '(?:8(?:5(?:[03]1|[14]0|85|5[58])|601))',
     '912' => '(?:(?:8(?:5(?:[58]5|24|40|67)|6[68]6)|0292))',
     '913' => '(?:8(?:5(?:[01]1|33|55|77|8[58])|611))',
@@ -874,7 +874,7 @@ our %ZIP_TABLE = (
     '915' => '(?:(?:8(?:5(?:01|55|77|1[015]|3[03]|2[04]|8[568])|666)|0292|1195))',
     '916' => '(?:(?:8(?:5(?:67|5[058]|8[58]|1[05]|0[1578])|6(?:[468]6|01))|0(?:29[235]|[14]92)|1198))',
     '917' => '(?:(?:8(?:5(?:[24]4|33|77|6[17]|5[058]|1[12]|0[57]|8[0458])|6(?:01|86))|0(?:29[378]|[13]98)))',
-    '918' => '(?:8(?:5(?:4[03]|6[05-8]|1[0158]|7[0578]|2[0235]|3[037]|5[02568]|8[03568]|0[1-3589])|6(?:68|8[168])))',
+    '918' => '(?:8(?:5(?:6[05-7]|4[03]|1[0158]|7[0578]|2[0235]|3[037]|5[02568]|8[03568]|0[1-3589])|6(?:68|8[168])))',
     '919' => '(?:(?:0(?:59[2578]|69[2578]|[124]92|898)|1(?:39[235-7]|[15]92)|2(?:29[2-4]|392)))',
     '920' => '(?:(?:8(?:5(?:2[0-25]|4[013-5]|3[0135-9]|1[0-35-8]|7[0357]|0[1-57-9]|5[0-8]|[68][035-8])|6(?:2[0-358]|8[1568]|5[04-8]|0[125-79]|3[0-37-9]|7[0146-8]|4[0-248]|6[0156]|1[0-69])|7(?:[67]7|30|9[3-7]|0[17]|2[189]|1[0189]))|0(?:3(?:8[135-8]|9[23568])|29[235]|192)|1(?:1(?:92|8[0-245])|39[2367])|2(?:39[2-5]|19[256])|3198))',
     '921' => '(?:8(?:5(?:6[0-245]|5[025]|1[0-2578]|3[0-269]|0[15-8]|2[035-79]|8[0-589]|4[1468]|7[1-79])|6(?:01|16|50|3[079]|2[01])|798))',
